==> dnacentersdk-2.4.8-py3-none-any.whl: dnacentersdk/models/validators/v2_2_3_3/jsd_b07f187b7456c8bbb6088a2f24dcee.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center AddIPPoolInSDAVirtualNetwork data model.

Copyright (c) 2019-2021 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import absolute_import, division, print_function, unicode_literals

import json
from builtins import *

import fastjsonschema

from dnacentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorB07F187B7456C8Bbb6088A2F24Dcee(object):
    """AddIPPoolInSDAVirtualNetwork request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorB07F187B7456C8Bbb6088A2F24Dcee, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "properties": {
                "authenticationPolicyName": {
                "type": "string"
                },
                "ipPoolName": {
                "type": "string"
                },
                "isL2FloodingEnabled": {
                "type": "boolean"
                },
                "isThisCriticalPool": {
                "type": "boolean"
                },
                "isWirelessPool": {
                "type": "string"
                },
                "poolType": {
                "type": "string"
                },
                "scalableGroupName": {
                "type": "string"
                },
                "siteNameHierarchy": {
                "type": "string"
                },
                "trafficType": {
                "enum": [
                "data",
                "voice"
                ],
                "type": "string"
                },
                "virtualNetworkName": {
                "type": "string"
                },
                "vlanName": {
                "type": "string"
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> dnacentersdk-2.5.5-py3-none-any.whl: dnacentersdk/models/validators/v2_2_1/jsd_b07f187b7456c8bbb6088a2f24dcee.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center addIPPoolInSDAVirtualNetwork data model.

Copyright (c) 2019-2021 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from __future__ import absolute_import, division, print_function, unicode_literals

import json
from builtins import *

import fastjsonschema

from dnacentersdk.exceptions import MalformedRequest


class JSONSchemaValidatorB07F187B7456C8Bbb6088A2F24Dcee(object):
    """addIPPoolInSDAVirtualNetwork request schema definition."""
    def __init__(self):
        super(JSONSchemaValidatorB07F187B7456C8Bbb6088A2F24Dcee, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "$schema": "http://json-schema.org/draft-04/schema#",
                "items": {
                "properties": {
                "authenticationPolicyName": {
                "type": "string"
                },
                "ipPoolName": {
                "type": "string"
                },
                "isL2FloodingEnabled": {
                "type": "boolean"
                },
                "isThisCriticalPool": {
                "type": "boolean"
                },
                "poolType": {
                "type": "string"
                },
                "scalableGroupName": {
                "type": "string"
                },
                "trafficType": {
                "type": "string"
                },
                "virtualNetworkName": {
                "type": "string"
                }
                },
                "type": "object"
                },
                "type": "array"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )
